@@ -16,7 +16,9 @@ def R_literal(item):
         return '%d' % item
     elif isinstance(item, list) or isinstance(item, tuple):
         if not len(item) or not (isinstance(item[0], list) or isinstance(item[0], tuple)):
-            return 'c(' + ','.join( R_literal(subitem) for subitem in item ) + ')'
+            return 'c(' + ',\n'.join( R_literal(subitem) for subitem in item ) + ')'
+        # Note: newline because R will eventually barf if fed a long enough single line.
+        
         
         #Matrix
         ncol = len(item[0])
@@ -33,6 +35,19 @@ def R_literal(item):
         assert False, "Can't encode %s" % repr(item)
 
 def run_script(script, only_tell=False, silent=False, **kwargs):
+    script = (
+            ''.join([
+            key + ' <- ' + R_literal(kwargs[key]) + '\n'
+            for key in kwargs
+        ]) + 
+        '\n' +
+        script
+        )
+               
+    if only_tell:
+        print script
+        return
+
     script = (
         '{\n'
         "options(warn=1,error=function() {\n"
@@ -43,19 +58,10 @@ def run_script(script, only_tell=False, silent=False, **kwargs):
         "  options(bitmapType='cairo');\n"
         "}\n"
         '\n' +
-        ''.join([
-            key + ' <- ' + R_literal(kwargs[key]) + '\n'
-            for key in kwargs
-        ]) + 
-        '\n' +
         script +
         '\ninvisible();\n'   #Rscript prints the return value of top level expressions. No thanks.
         '}\n'        
     )
-       
-    if only_tell:
-        print script
-        return
         
     if silent:
         stdout = subprocess.PIPE
@@ -241,8 +247,9 @@ Smyth, G. K. (2004). Linear models and empirical Bayes methods for assessing
 differential expression in microarray experiments. Statistical Applications 
 in Genetics and Molecular Biology 3, No. 1, Article 3.
 
-Law, CW, Chen, Y, Shi, W, and Smyth, GK (2011). Voom! Variance modelling 
-powers an empirical Bayes linear modelling pipeline for RNA-Seq data. Submitted.
+Law, CW, Chen, Y, Shi, W, and Smyth, GK (2014). Voom: precision weights
+unlock linear model analysis tools for RNA-seq read counts. Genome Biology,
+Vol 15(2).
 """,  
 'nullvoom' : """    
 Uses BioConductor package limma, with voom, to fit the null model 
